ProjectSummary class

Constructors

ProjectSummary({required TechStack techStack, required ArchitecturePattern architecturePattern, int totalFiles = 0, int screens = 0, int models = 0, int repositories = 0, int services = 0, List<String> learningPath = const []})

Properties

architecturePattern ArchitecturePattern
final
hashCode int
The hash code for this object.
no setterinherited
learningPath List<String>
final
models int
final
repositories int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screens int
final
services int
final
techStack TechStack
final
totalFiles int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited