TechStack class

Constructors

TechStack({List<String> stateManagement = const [], List<String> routing = const [], List<String> corePackages = const []})

Properties

corePackages List<String>
final
hashCode int
The hash code for this object.
no setterinherited
routing List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateManagement List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited