DartParser class
Core parser that analyzes Dart projects and extracts architecture metadata.
It traverses the lib/ directory to map dependencies and class types.
Constructors
- DartParser({required String rootPath})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- libPath ↔ String
-
latefinal
- packageName ↔ String
-
latefinal
- rootPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseProject(
) → Future< List< Node> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited